@@ -269,8 +269,8 @@ class DescribeActivationsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["DescribeActivationsFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[DescribeActivationsFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeActivationsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeActivations.paginate)
@@ -289,8 +289,8 @@ class DescribeAssociationExecutionTargetsPaginator(Boto3Paginator):
         *,
         AssociationId: str,
         ExecutionId: str,
-        Filters: Sequence["AssociationExecutionTargetsFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[AssociationExecutionTargetsFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeAssociationExecutionTargetsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeAssociationExecutionTargets.paginate)
@@ -308,8 +308,8 @@ class DescribeAssociationExecutionsPaginator(Boto3Paginator):
         self,
         *,
         AssociationId: str,
-        Filters: Sequence["AssociationExecutionFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[AssociationExecutionFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeAssociationExecutionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeAssociationExecutions.paginate)
@@ -326,8 +326,8 @@ class DescribeAutomationExecutionsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["AutomationExecutionFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[AutomationExecutionFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeAutomationExecutionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeAutomationExecutions.paginate)
@@ -345,9 +345,9 @@ class DescribeAutomationStepExecutionsPaginator(Boto3Paginator):
         self,
         *,
         AutomationExecutionId: str,
-        Filters: Sequence["StepExecutionFilterTypeDef"] = ...,
+        Filters: Sequence[StepExecutionFilterTypeDef] = ...,
         ReverseOrder: bool = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeAutomationStepExecutionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeAutomationStepExecutions.paginate)
@@ -364,8 +364,8 @@ class DescribeAvailablePatchesPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["PatchOrchestratorFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[PatchOrchestratorFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeAvailablePatchesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeAvailablePatches.paginate)
@@ -380,7 +380,7 @@ class DescribeEffectiveInstanceAssociationsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, InstanceId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, InstanceId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeEffectiveInstanceAssociationsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeEffectiveInstanceAssociations.paginate)
@@ -395,7 +395,7 @@ class DescribeEffectivePatchesForPatchBaselinePaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, BaselineId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, BaselineId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeEffectivePatchesForPatchBaselineResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeEffectivePatchesForPatchBaseline.paginate)
@@ -410,7 +410,7 @@ class DescribeInstanceAssociationsStatusPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, InstanceId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, InstanceId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeInstanceAssociationsStatusResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInstanceAssociationsStatus.paginate)
@@ -427,9 +427,9 @@ class DescribeInstanceInformationPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        InstanceInformationFilterList: Sequence["InstanceInformationFilterTypeDef"] = ...,
-        Filters: Sequence["InstanceInformationStringFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        InstanceInformationFilterList: Sequence[InstanceInformationFilterTypeDef] = ...,
+        Filters: Sequence[InstanceInformationStringFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeInstanceInformationResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInstanceInformation.paginate)
@@ -444,7 +444,7 @@ class DescribeInstancePatchStatesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, InstanceIds: Sequence[str], PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, InstanceIds: Sequence[str], PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeInstancePatchStatesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInstancePatchStates.paginate)
@@ -462,8 +462,8 @@ class DescribeInstancePatchStatesForPatchGroupPaginator(Boto3Paginator):
         self,
         *,
         PatchGroup: str,
-        Filters: Sequence["InstancePatchStateFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[InstancePatchStateFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeInstancePatchStatesForPatchGroupResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInstancePatchStatesForPatchGroup.paginate)
@@ -481,8 +481,8 @@ class DescribeInstancePatchesPaginator(Boto3Paginator):
         self,
         *,
         InstanceId: str,
-        Filters: Sequence["PatchOrchestratorFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[PatchOrchestratorFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeInstancePatchesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInstancePatches.paginate)
@@ -497,7 +497,7 @@ class DescribeInventoryDeletionsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, DeletionId: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, DeletionId: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeInventoryDeletionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeInventoryDeletions.paginate)
@@ -516,8 +516,8 @@ class DescribeMaintenanceWindowExecutionTaskInvocationsPaginator(Boto3Paginator)
         *,
         WindowExecutionId: str,
         TaskId: str,
-        Filters: Sequence["MaintenanceWindowFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[MaintenanceWindowFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeMaintenanceWindowExecutionTaskInvocationsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowExecutionTaskInvocations.paginate)
@@ -535,8 +535,8 @@ class DescribeMaintenanceWindowExecutionTasksPaginator(Boto3Paginator):
         self,
         *,
         WindowExecutionId: str,
-        Filters: Sequence["MaintenanceWindowFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[MaintenanceWindowFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeMaintenanceWindowExecutionTasksResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowExecutionTasks.paginate)
@@ -554,8 +554,8 @@ class DescribeMaintenanceWindowExecutionsPaginator(Boto3Paginator):
         self,
         *,
         WindowId: str,
-        Filters: Sequence["MaintenanceWindowFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[MaintenanceWindowFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeMaintenanceWindowExecutionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowExecutions.paginate)
@@ -573,10 +573,10 @@ class DescribeMaintenanceWindowSchedulePaginator(Boto3Paginator):
         self,
         *,
         WindowId: str = ...,
-        Targets: Sequence["TargetTypeDef"] = ...,
+        Targets: Sequence[TargetTypeDef] = ...,
         ResourceType: MaintenanceWindowResourceTypeType = ...,
-        Filters: Sequence["PatchOrchestratorFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[PatchOrchestratorFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeMaintenanceWindowScheduleResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowSchedule.paginate)
@@ -594,8 +594,8 @@ class DescribeMaintenanceWindowTargetsPaginator(Boto3Paginator):
         self,
         *,
         WindowId: str,
-        Filters: Sequence["MaintenanceWindowFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[MaintenanceWindowFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeMaintenanceWindowTargetsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowTargets.paginate)
@@ -613,8 +613,8 @@ class DescribeMaintenanceWindowTasksPaginator(Boto3Paginator):
         self,
         *,
         WindowId: str,
-        Filters: Sequence["MaintenanceWindowFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[MaintenanceWindowFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeMaintenanceWindowTasksResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowTasks.paginate)
@@ -631,8 +631,8 @@ class DescribeMaintenanceWindowsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["MaintenanceWindowFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[MaintenanceWindowFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeMaintenanceWindowsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindows.paginate)
@@ -649,9 +649,9 @@ class DescribeMaintenanceWindowsForTargetPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Targets: Sequence["TargetTypeDef"],
+        Targets: Sequence[TargetTypeDef],
         ResourceType: MaintenanceWindowResourceTypeType,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeMaintenanceWindowsForTargetResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeMaintenanceWindowsForTarget.paginate)
@@ -668,8 +668,8 @@ class DescribeOpsItemsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        OpsItemFilters: Sequence["OpsItemFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        OpsItemFilters: Sequence[OpsItemFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeOpsItemsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeOpsItems.paginate)
@@ -686,9 +686,9 @@ class DescribeParametersPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["ParametersFilterTypeDef"] = ...,
-        ParameterFilters: Sequence["ParameterStringFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[ParametersFilterTypeDef] = ...,
+        ParameterFilters: Sequence[ParameterStringFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeParametersResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeParameters.paginate)
@@ -705,8 +705,8 @@ class DescribePatchBaselinesPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["PatchOrchestratorFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[PatchOrchestratorFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribePatchBaselinesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribePatchBaselines.paginate)
@@ -723,8 +723,8 @@ class DescribePatchGroupsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["PatchOrchestratorFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[PatchOrchestratorFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribePatchGroupsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribePatchGroups.paginate)
@@ -744,7 +744,7 @@ class DescribePatchPropertiesPaginator(Boto3Paginator):
         OperatingSystem: OperatingSystemType,
         Property: PatchPropertyType,
         PatchSet: PatchSetType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribePatchPropertiesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribePatchProperties.paginate)
@@ -762,8 +762,8 @@ class DescribeSessionsPaginator(Boto3Paginator):
         self,
         *,
         State: SessionStateType,
-        Filters: Sequence["SessionFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[SessionFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeSessionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.DescribeSessions.paginate)
@@ -780,10 +780,10 @@ class GetInventoryPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["InventoryFilterTypeDef"] = ...,
+        Filters: Sequence[InventoryFilterTypeDef] = ...,
         Aggregators: Sequence["InventoryAggregatorTypeDef"] = ...,
-        ResultAttributes: Sequence["ResultAttributeTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        ResultAttributes: Sequence[ResultAttributeTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetInventoryResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetInventory.paginate)
@@ -803,7 +803,7 @@ class GetInventorySchemaPaginator(Boto3Paginator):
         TypeName: str = ...,
         Aggregator: bool = ...,
         SubType: bool = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetInventorySchemaResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetInventorySchema.paginate)
@@ -821,10 +821,10 @@ class GetOpsSummaryPaginator(Boto3Paginator):
         self,
         *,
         SyncName: str = ...,
-        Filters: Sequence["OpsFilterTypeDef"] = ...,
+        Filters: Sequence[OpsFilterTypeDef] = ...,
         Aggregators: Sequence["OpsAggregatorTypeDef"] = ...,
-        ResultAttributes: Sequence["OpsResultAttributeTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        ResultAttributes: Sequence[OpsResultAttributeTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetOpsSummaryResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetOpsSummary.paginate)
@@ -843,7 +843,7 @@ class GetParameterHistoryPaginator(Boto3Paginator):
         *,
         Name: str,
         WithDecryption: bool = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetParameterHistoryResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetParameterHistory.paginate)
@@ -862,9 +862,9 @@ class GetParametersByPathPaginator(Boto3Paginator):
         *,
         Path: str,
         Recursive: bool = ...,
-        ParameterFilters: Sequence["ParameterStringFilterTypeDef"] = ...,
+        ParameterFilters: Sequence[ParameterStringFilterTypeDef] = ...,
         WithDecryption: bool = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetParametersByPathResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetParametersByPath.paginate)
@@ -879,7 +879,7 @@ class ListAssociationVersionsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, AssociationId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, AssociationId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAssociationVersionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListAssociationVersions.paginate)
@@ -896,8 +896,8 @@ class ListAssociationsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        AssociationFilterList: Sequence["AssociationFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        AssociationFilterList: Sequence[AssociationFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAssociationsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListAssociations.paginate)
@@ -916,9 +916,9 @@ class ListCommandInvocationsPaginator(Boto3Paginator):
         *,
         CommandId: str = ...,
         InstanceId: str = ...,
-        Filters: Sequence["CommandFilterTypeDef"] = ...,
+        Filters: Sequence[CommandFilterTypeDef] = ...,
         Details: bool = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListCommandInvocationsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListCommandInvocations.paginate)
@@ -937,8 +937,8 @@ class ListCommandsPaginator(Boto3Paginator):
         *,
         CommandId: str = ...,
         InstanceId: str = ...,
-        Filters: Sequence["CommandFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[CommandFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListCommandsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListCommands.paginate)
@@ -955,10 +955,10 @@ class ListComplianceItemsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["ComplianceStringFilterTypeDef"] = ...,
+        Filters: Sequence[ComplianceStringFilterTypeDef] = ...,
         ResourceIds: Sequence[str] = ...,
         ResourceTypes: Sequence[str] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListComplianceItemsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListComplianceItems.paginate)
@@ -975,8 +975,8 @@ class ListComplianceSummariesPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["ComplianceStringFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[ComplianceStringFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListComplianceSummariesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListComplianceSummaries.paginate)
@@ -991,7 +991,7 @@ class ListDocumentVersionsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, Name: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, Name: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDocumentVersionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListDocumentVersions.paginate)
@@ -1008,9 +1008,9 @@ class ListDocumentsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        DocumentFilterList: Sequence["DocumentFilterTypeDef"] = ...,
-        Filters: Sequence["DocumentKeyValuesFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        DocumentFilterList: Sequence[DocumentFilterTypeDef] = ...,
+        Filters: Sequence[DocumentKeyValuesFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDocumentsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListDocuments.paginate)
@@ -1027,8 +1027,8 @@ class ListOpsItemEventsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["OpsItemEventFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[OpsItemEventFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListOpsItemEventsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListOpsItemEvents.paginate)
@@ -1046,8 +1046,8 @@ class ListOpsItemRelatedItemsPaginator(Boto3Paginator):
         self,
         *,
         OpsItemId: str = ...,
-        Filters: Sequence["OpsItemRelatedItemsFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[OpsItemRelatedItemsFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListOpsItemRelatedItemsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListOpsItemRelatedItems.paginate)
@@ -1064,8 +1064,8 @@ class ListOpsMetadataPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["OpsMetadataFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[OpsMetadataFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListOpsMetadataResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListOpsMetadata.paginate)
@@ -1082,8 +1082,8 @@ class ListResourceComplianceSummariesPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["ComplianceStringFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[ComplianceStringFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListResourceComplianceSummariesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListResourceComplianceSummaries.paginate)
@@ -1098,7 +1098,7 @@ class ListResourceDataSyncPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, SyncType: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, SyncType: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListResourceDataSyncResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListResourceDataSync.paginate)
