@@ -38,7 +38,7 @@ class CommandExecutedWaiter(Boto3Waiter):
         CommandId: str,
         InstanceId: str,
         PluginName: str = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Waiter.CommandExecuted.wait)
